multiformats.multibase.raw
==========================

.. automodule:: multiformats.multibase.raw

CustomEncoding
--------------

.. autoclass:: multiformats.multibase.raw.CustomEncoding
    :members:

exists
------

.. autofunction:: multiformats.multibase.raw.exists

get
---

.. autofunction:: multiformats.multibase.raw.get

register
--------

.. autofunction:: multiformats.multibase.raw.register

unregister
----------

.. autofunction:: multiformats.multibase.raw.unregister
